package org.bitbucket.bradleysmithllc.etlunit;

import org.bitbucket.bradleysmithllc.etlunit.context.VariableContext;
import org.bitbucket.bradleysmithllc.etlunit.parser.ETLTestClass;
import org.bitbucket.bradleysmithllc.etlunit.parser.ETLTestMethod;
import org.bitbucket.bradleysmithllc.etlunit.parser.ETLTestOperation;
import org.bitbucket.bradleysmithllc.etlunit.parser.ETLTestValueObject;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;

public class LogListenerLogProxy extends NullClassListener implements Log
{
	private final LogListener deferred;
	private ETLTestClass currentClass;
	private ETLTestMethod currentMethod;
	private ETLTestOperation currentOperation;

	private final DateFormat df = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");

	public LogListenerLogProxy(LogListener deferred)
	{
		this.deferred = deferred;
	}

	@Override
	public void info(String message)
	{
		deferred.log(LogListener.message_type.info, message, currentClass, currentMethod, currentOperation);
	}

	@Override
	public void debug(String message)
	{
		deferred.log(LogListener.message_type.debug, message, currentClass, currentMethod, currentOperation);
	}

	@Override
	public void severe(String message)
	{
		deferred.log(LogListener.message_type.severe, message, currentClass, currentMethod, currentOperation);
	}

	@Override
	public void severe(String message, Throwable thr)
	{
		deferred.log(LogListener.message_type.severe, thr, message, currentClass, currentMethod, currentOperation);
	}

	@Override
	public void suspend(boolean state)
	{
	}

	@Override
	public void begin(ETLTestClass cl, VariableContext context)
			throws TestAssertionFailure, TestExecutionError, TestWarning
	{
		currentClass = cl;
		info("Begin processing test class " + df.format(new Date()));
	}

	@Override
	public void begin(ETLTestMethod mt, VariableContext context)
			throws TestAssertionFailure, TestExecutionError, TestWarning
	{
		currentMethod = mt;
	}

	@Override
	public void begin(ETLTestOperation op, ETLTestValueObject parameters, VariableContext vcontext, ExecutionContext econtext)
			throws TestAssertionFailure, TestExecutionError, TestWarning
	{
		currentOperation = op;
	}

	@Override
	public void end(ETLTestOperation op, ETLTestValueObject parameters, VariableContext vcontext, ExecutionContext econtext)
			throws TestAssertionFailure, TestExecutionError, TestWarning
	{
		currentOperation = null;
	}

	@Override
	public void end(ETLTestMethod mt, VariableContext context)
			throws TestAssertionFailure, TestExecutionError, TestWarning
	{
		currentMethod = null;
	}

	@Override
	public void end(ETLTestClass cl, VariableContext context) throws TestAssertionFailure, TestExecutionError, TestWarning
	{
		currentClass = null;
	}
}